Data presented in Heasman & Reid (1961), originally gathered and analyzed by Brimblecombe et al (1958). The data set describes 664 outbreaks of the common cold in 72 families over two years. All families consists of two parents and three children. The data is available in aggregated form as presented in the paper, with counts of the number of outbreaks that belong to a given classification.
heasman_reid_1961_chainsheasman_reid_1961_crowding
heasman_reid_1961_intro_case_status
heasman_reid_1961_intro_case_status
heasman_reid_1961_crowding
An object of class data.frame with 24 rows and 2 columns.
An object of class data.frame with 5 rows and 5 columns.
An object of class data.frame with 5 rows and 4 columns.
Each outbreak was classified to a specific chain suitable for analysis by the Chain Binomial model by Heasman & Reid (1961), Table V.
heasman_reid_1961_chains: A data frame with 24 rows and 2 columns:
the number of infected in each generation, separated by '-', ie the Chain.
Number of outbreaks
Each outbreak classified according to the degree of domestic overcrowding. Heasman & Reid (1961), Table IV. Overcrowded homes have either one or two rooms, crowded homes have three rooms, while uncrowded homes have more than three rooms.
heasman_reid_1961_crowding: A data frame with 5 rows and 4 columns:
The number of cases in the outbreak, in addition to the primary case.
Number of outbreaks that belong to the overcrowded household category.
Number of outbreaks that belong to the crowded household category.
Number of outbreaks that belong to the uncrowded household category.
Each outbreak classified according to who the the introducing case was. Heasman & Reid (1961), Table II.
heasman_reid_1961_intro_case_status: A data frame with 5 rows and 5 columns:
The number of cases in the outbreak, in addition to the primary case.
Number of outbreaks with father as the index case.
Number of outbreaks with mother as the index case.
Number of outbreaks with a school child as the index case.
Number of outbreaks with a pre-school child as the index case.
Heasman & Reid (1961) Theory And Observation In Family Epidemics Of The Common Cold. Brit. J. prev. soc. Med.
Brimblecombe et al (1958) Family Studies Of Respiratory Infections. British Medical Journal.